@@ -10,7 +10,8 @@
 #'                strings \code{""}.
 #' @param na.omit logical: if \code{TRUE}, missing values (\code{NA}) are also
 #'                omitted from the vector.
-#' @param check   logical: if \code{TRUE}, argument specification is checked.
+#' @param check   logical: if \code{TRUE} (default), argument specification is
+#'                checked.
 #'
 #' @author
 #' Takuya Yanagida \email{takuya.yanagida@@univie.ac.at}
@@ -25,37 +26,37 @@
 #' @export
 #'
 #' @examples
-#' #--------------------------------------
+#' #----------------------------------------------------------------------------
 #' # Charater vector
 #' x.chr <- c("a", "", "c", NA, "", "d", "e", NA)
 #'
-#' # Omit character string ""
+#' # Example 1: Omit character string ""
 #' chr.omit(x.chr)
 #'
-#' # Omit character string "" and missing values (NA)
+#' # Example 2: Omit character string "" and missing values (NA)
 #' chr.omit(x.chr, na.omit = TRUE)
 #'
-#' # Omit character string "c" and "e"
+#' # Example 3: Omit character string "c" and "e"
 #' chr.omit(x.chr, omit = c("c", "e"))
 #'
-#' # Omit character string "c", "e", and missing values (NA)
+#' # Example 4: Omit character string "c", "e", and missing values (NA)
 #' chr.omit(x.chr, omit = c("c", "e"), na.omit = TRUE)
 #'
-#' #--------------------------------------
+#' #----------------------------------------------------------------------------
 #' # Numeric vector
 #' x.num <- c(1, 2, NA, 3, 4, 5, NA)
 #'
-#' # Omit values 2 and 4
+#' # Example 5: Omit values 2 and 4
 #' chr.omit(x.num, omit = c(2, 4))
 #'
-#' # Omit values 2, 4, and missing values (NA)
+#' # Example 6: Omit values 2, 4, and missing values (NA)
 #' chr.omit(x.num, omit = c(2, 4), na.omit = TRUE)
 #'
-#' #--------------------------------------
+#' #----------------------------------------------------------------------------
 #' # Factor
 #' x.factor <- factor(letters[1:10])
 #'
-#' # Omit factor levels "a", "c", "e", and "g"
+#' # Example 7: Omit factor levels "a", "c", "e", and "g"
 #' chr.omit(x.factor, omit = c("a", "c", "e", "g"))
 chr.omit <- function(x, omit = "", na.omit = FALSE, check = TRUE) {
 
@@ -83,18 +84,10 @@ chr.omit <- function(x, omit = "", na.omit = FALSE, check = TRUE) {
 
     # Check input 'omit': Values in 'x'?
     na.x <- vapply(omit, function(y) !y %in% x, FUN.VALUE = logical(1))
-    if (isTRUE(any(na.x))) {
-
-      warning(paste0("Values specified in the argument 'omit' were not found in 'x': ",
-                     paste(omit[na.x], collapse = ", ")), call. = FALSE)
-    }
+    if (isTRUE(any(na.x))) { warning(paste0("Values specified in the argument 'omit' were not found in 'x': ", paste(omit[na.x], collapse = ", ")), call. = FALSE) }
 
     # Check input 'na.omit'
-    if (isTRUE(!is.logical(na.omit))) {
-
-      stop("Please specify TRUE or FALSE for the argument 'na.omit'.", call. = FALSE)
-
-    }
+    if (isTRUE(!is.logical(na.omit))) { stop("Please specify TRUE or FALSE for the argument 'na.omit'.", call. = FALSE) }
 
   }
 
