@@ -94,11 +94,12 @@
 #'                        \code{k - 1} classes model and 100 random sets of starting
 #'                        values in the initial stage and 50 optimizations in the
 #'                        final stage are used for the \code{k} class model.
-#' @param processors      an integer value for specifying the \code{PROCESSORS}
-#'                        option in Mplus. The value specifies the number of
-#'                        processors and threads to be used for parallel computing
-#'                        to increase computational speed. By default, 8 processors
-#'                        and threads are used for parallel computing.
+#' @param processors      a vector of two integer values for specifying the
+#'                        \code{PROCESSORS} option in Mplus. The values specifies
+#'                        the number of processors and threads to be used for
+#'                        parallel computing to increase computational speed. By
+#'                        default, 8 processors and threads are used for parallel
+#'                        computing.
 #' @param output          a character string or character vector specifying the
 #'                        \code{TECH} options in the \code{OUTPUT} section in Mplus,
 #'                        i.e., \code{SVALUES} to request input statements that
@@ -236,7 +237,7 @@ mplus.lca <- function(x, ind = NULL,
                       file = "Data_LCA.dat", write = c("all", "folder", "data", "input"),
                       useobservations = NULL, missing = -99, classes = 6, estimator = "MLR",
                       starts = c(100, 50), stiterations = 10, lrtbootstrap = 1000,
-                      lrtstarts = c(0, 0, 100, 50), processors = 8,
+                      lrtstarts = c(0, 0, 100, 50), processors = c(8, 8),
                       output = c("all", "SVALUES", "CINTERVAL", "TECH7", "TECH8", "TECH11", "TECH14"),
                       replace.inp = FALSE, run.mplus = FALSE, Mplus = "Mplus",
                       replace.out = c("always", "never", "modifiedDate"), check = TRUE) {
@@ -309,7 +310,7 @@ mplus.lca <- function(x, ind = NULL,
     if (isTRUE(lrtstarts[4L] > lrtstarts[3L])) { stop("The fourth value must be less than or equal the third value in the argument 'lrtstarts'.", call. = FALSE) }
 
     # Check 'processors'
-    if (isTRUE(length(processors) != 1L || processors %% 1L != 0L)) { stop("Please specify an integer value for the argument 'processors'.", call. = FALSE) }
+    if (isTRUE(length(processors) %in% c(1L, 2L))) { stop("Please specify a vector with two integer values for the argument 'processors'.", call. = FALSE) }
 
     ## Check input 'print' ##
     if (isTRUE(!all(output %in% c("all", "SVALUES", "CINTERVAL", "TECH7", "TECH8", "TECH11", "TECH14")))) { stop("Character string in the argument 'output' does not match with \"SVALUES\", \"CINTERVAL\", \"TECH7\", \"TECH8\", \"TECH11\", or \"TECH14\".", call. = FALSE) }
