@@ -5,17 +5,28 @@
 #' construct, shared cluster-level construct, and configural cluster construct by
 #' calling the \code{cfa} function in the R package \pkg{lavaan}.
 #'
-#' @param x            a matrix or data frame. Multilevel confirmatory factor
+#' @param ...          a matrix or data frame. Multilevel confirmatory factor
 #'                     analysis based on a measurement model with one factor
 #'                     at the Within level and one factor at the Between level
 #'                     comprising all variables in the matrix or data frame is
 #'                     conducted. Note that the cluster variable specified in
 #'                     \code{cluster} is excluded from \code{x} when specifying
 #'                     the argument \code{cluster} using the variable name of the
-#'                     cluster variable.
+#'                     cluster variable. Alternatively, an expression indicating
+#'                     the variable names in \code{data} e.g.,
+#'                     \code{multilevel.omega(x1, x2, x3, data = dat, cluster = "cluster)}.
+#'                     Note that the operators \code{.}, \code{+}, \code{-},
+#'                     \code{~}, \code{:}, \code{::}, and \code{!} can also be
+#'                     used to select variables, see 'Details' in the
+#'                     \code{\link{df.subset}} function.
+#' @param data         a data frame when specifying one or more variables in the
+#'                     argument \code{...}. Note that the argument is \code{NULL}
+#'                     when specifying a matrix or data frame for the argument
+#'                     \code{...}.
 #' @param cluster      either a character string indicating the variable name of
-#'                     the cluster variable in 'x' or a vector representing the
-#'                     nested grouping structure (i.e., group or cluster variable).
+#'                     the cluster variable in \code{...} or \code{data}, or a
+#'                     vector representing the nested grouping structure (i.e.,
+#'                     group or cluster variable).
 #' @param rescov       a character vector or a list of character vectors for specifying
 #'                     residual covariances at the Within level, e.g. \code{rescov = c("x1", "x2")}
 #'                     for specifying a residual covariance between indicators \code{x1}
@@ -60,12 +71,19 @@
 #'                     i.e. these values are converted to \code{NA} before conducting
 #'                     the analysis. Note that \code{as.na()} function is only
 #'                     applied to \code{x} but not to \code{cluster}.
-#' @param write        a character string for writing the results into a Excel
-#'                     file naming a file with or without file extension '.xlsx',
-#'                     e.g., \code{"Results.xlsx"} or \code{"Results"}.
-#' @param check        logical: if \code{TRUE}, argument specification, convergence
-#'                     and model identification is checked.
-#' @param output       logical: if \code{TRUE}, output is shown.
+#' @param write        a character string naming a file for writing the output into
+#'                     either a text file with file extension \code{".txt"} (e.g.,
+#'                     \code{"Output.txt"}) or Excel file with file extention
+#'                     \code{".xlsx"}  (e.g., \code{"Output.xlsx"}). If the file
+#'                     name does not contain any file extension, an Excel file will
+#'                     be written.
+#' @param append       logical: if \code{TRUE} (default), output will be appended
+#'                     to an existing text file with extension \code{.txt} specified
+#'                     in \code{write}, if \code{FALSE} existing text file will be
+#'                     overwritten.
+#' @param check        logical: if \code{TRUE} (default), argument specification,
+#'                     convergence and model identification is checked.
+#' @param output       logical: if \code{TRUE} (default), output is shown.
 #'
 #' @author
 #' Takuya Yanagida \email{takuya.yanagida@@univie.ac.at}
@@ -89,7 +107,8 @@
 #' @return
 #' \item{\code{call}}{function call}
 #' \item{\code{type}}{type of analysis}
-#' \item{\code{data}}{matrix or data frame specified in \code{x}}
+#' \item{\code{data}}{data frame specified in \code{x} including the group variable
+#'                    specified in \code{cluster}}
 #' \item{\code{args}}{specification of function arguments}
 #' \item{\code{model}}{specified model}
 #' \item{\code{model.fit}}{fitted lavaan object (\code{mod.fit})}
@@ -111,78 +130,153 @@
 #' # Load data set "Demo.twolevel" in the lavaan package
 #' data("Demo.twolevel", package = "lavaan")
 #'
-#' #---------------------------
+#' #----------------------------------------------------------------------------
 #' # Cluster variable specification
 #'
-#' # Cluster variable 'cluster' in 'x'
-#' multilevel.omega(Demo.twolevel[,c("y1", "y2", "y3", "y4", "cluster")],
-#'                  cluster = "cluster")
+#' # Example 1a: Cluster variable 'cluster' in 'x'
+#' multilevel.omega(Demo.twolevel[,c("y1", "y2", "y3", "y4", "cluster")], cluster = "cluster")
 #'
-#' # Cluster variable 'cluster' not in 'x'
-#' multilevel.omega(Demo.twolevel[,c("y1", "y2", "y3", "y4")],
-#'                  cluster = Demo.twolevel$cluster)
+#' # Example 1b: Cluster variable 'cluster' not in 'x'
+#' multilevel.omega(Demo.twolevel[,c("y1", "y2", "y3", "y4")], cluster = Demo.twolevel$cluster)
 #'
-#' #---------------------------
+#' # Example 1c: Alternative specification using the 'data' argument
+#' multilevel.omega(y1:y4, data = Demo.twolevel, cluster = "cluster")
+#'
+#' #----------------------------------------------------------------------------
 #' # Type of construct
 #'
-#' # Within-Cluster Construct
+#' # Example 2a: Within-Cluster Construct
 #' multilevel.omega(Demo.twolevel[,c("y1", "y2", "y3", "y4")],
 #'                  cluster = Demo.twolevel$cluster, const = "within")
 #'
-#' # Shared Cluster-Level Construct
+#' # Example 2b: Shared Cluster-Level Construct
 #' multilevel.omega(Demo.twolevel[,c("y1", "y2", "y3", "y4")],
 #'                  cluster = Demo.twolevel$cluster, const = "shared")
 #'
-#' # Configural Construct
+#' # Example 2c: Configural Construct
 #' multilevel.omega(Demo.twolevel[,c("y1", "y2", "y3", "y4")],
 #'                  cluster = Demo.twolevel$cluster, const = "config")
 #'
-#' #---------------------------
+#' #----------------------------------------------------------------------------
 #' # Residual covariance at the Within level and residual variance at the Between level
 #'
-#' # Residual covariance between "y4" and "y5" at the Within level
+#' # Example 3a: Residual covariance between "y4" and "y5" at the Within level
 #' multilevel.omega(Demo.twolevel[,c("y1", "y2", "y3", "y4")],
 #'                  cluster = Demo.twolevel$cluster, const = "config",
 #'                  rescov = c("y3", "y4"))
 #'
-#' # Residual variances of 'y1' at the Between level fixed at 0
+#' # Example 3b: Residual variances of 'y1' at the Between level fixed at 0
 #' multilevel.omega(Demo.twolevel[,c("y1", "y2", "y3", "y4")],
 #'                  cluster = Demo.twolevel$cluster, const = "config",
 #'                  fix.resid = c("y1", "y2"), digits = 3)
 #'
-#' #---------------------------
+#' #----------------------------------------------------------------------------
 #' # Write results
 #'
-#' # Assign results into an object and write results into an Excel file
+#' # Example 4a: Write results into a text file
+#' multilevel.omega(Demo.twolevel[,c("y1", "y2", "y3", "y4")],
+#'                  cluster = Demo.twolevel$cluster, write = "Multilevel_Omega.txt")
+#'
+#' # Example 4b: Write results into a Excel file
+#' multilevel.omega(Demo.twolevel[,c("y1", "y2", "y3", "y4")],
+#'                  cluster = Demo.twolevel$cluster, write = "Multilevel_Omega.xlsx")
+#'
+#' # Example 4b: Assign results into an object and write results into an Excel file
 #' mod <- multilevel.omega(Demo.twolevel[,c("y1", "y2", "y3", "y4")],
 #'                         cluster = Demo.twolevel$cluster, output = FALSE)
 #'
 #' # Write results into an Excel file
 #' write.result(mod, "Multilevel_Omega.xlsx")
-#'
-#' # Write results into an Excel file
-#' multilevel.omega(Demo.twolevel[,c("y1", "y2", "y3", "y4")],
-#'                  cluster = Demo.twolevel$cluster, write = "Multilevel_Omega.xlsx")
 #' }
-multilevel.omega <- function(x, cluster, rescov = NULL, const = c("within", "shared", "config"),
+multilevel.omega <- function(..., data = NULL, cluster, rescov = NULL,
+                             const = c("within", "shared", "config"),
                              fix.resid = NULL, optim.method = c("nlminb", "em"),
                              missing = c("listwise", "fiml"), nrep = 100000, seed = NULL,
                              conf.level = 0.95, print = c("all", "omega", "item"),
-                             digits = 2, as.na = NULL, write = NULL, check = TRUE,
-                             output = TRUE) {
+                             digits = 2, as.na = NULL, write = NULL, append = TRUE,
+                             check = TRUE, output = TRUE) {
 
   #_____________________________________________________________________________
   #
   # Initial Check --------------------------------------------------------------
 
-  # Check if input 'x' is missing or Null
-  if (isTRUE(missing(x) || is.null(x))) { stop("Please specify a matrix or data frame for the argument 'x'.", call. = FALSE) }
+  # Check if input '...' is missing
+  if (isTRUE(missing(...))) { stop("Please specify the argument '...'.", call. = FALSE) }
 
-  # Check if input 'x' is a matrix or a data frame
-  if (isTRUE(!is.matrix(x) && !is.data.frame(x))) { stop("Please specify a matrix or a data frame for the argument 'x'.", call. = FALSE) }
+  # Check if input '...' is NULL
+  if (isTRUE(is.null(substitute(...)))) { stop("Input specified for the argument '...' is NULL.", call. = FALSE) }
 
-  # Check if input 'cluster' is missing or null
-  if (isTRUE(missing(cluster) || is.null(cluster))) { stop("Please specify a character string or a vector for the argument 'cluster'.", call. = FALSE) }
+  # Check if input 'data' is data frame
+  if (isTRUE(!is.null(data) && !is.data.frame(data))) { stop("Please specify a data frame for the argument 'data'.", call. = FALSE) }
+
+  # Check input 'cluster'
+  if (isTRUE(missing(cluster))) { stop("Please specify a variable name or vector representing the grouping structure for the argument 'cluster'.", call. = FALSE) }
+
+  # Check if input 'cluster' is NULL
+  if (isTRUE(is.null(cluster))) { stop("Input specified for the argument 'cluster' is NULL.", call. = FALSE) }
+
+  #_____________________________________________________________________________
+  #
+  # Data -----------------------------------------------------------------------
+
+  #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+  ## Data using the argument 'data' ####
+
+  if (isTRUE(!is.null(data))) {
+
+    # Variable names
+    var.names <- .var.names(..., data = data, cluster = cluster, check.chr = "a matrix or data frame")
+
+    # Extract data
+    x <- data[, var.names]
+
+    # Cluster variable
+    cluster <- data[, cluster]
+
+  #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+  ## Data without using the argument 'data' ####
+
+  } else {
+
+    # Extract data
+    x <- eval(..., enclos = parent.frame())
+
+    # Data and cluster
+    var.group <- .var.group(data = x, cluster = cluster)
+
+    # Data
+    if (isTRUE(!is.null(var.group$data)))  { x <- var.group$data }
+
+    # Cluster variable
+    if (isTRUE(!is.null(var.group$cluster))) { cluster <- var.group$cluster }
+
+  }
+
+  #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+  ## Manifest variables ####
+
+  # Cluster variable in the data
+  if (isTRUE(length(cluster) == 1L)) { var <- colnames(x)[!colnames(x) %in% cluster] } else { var <- colnames(x) }
+
+  #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+  ## Data frame with Cluster Variable ####
+
+  # Cluster variable in the data
+  if (isTRUE(length(cluster) == 1L)) {
+
+    x <- data.frame(x[, var], .cluster = x[, cluster], stringsAsFactors = FALSE)
+
+    # Cluster variable specified in the argument 'cluster'
+  } else {
+
+    x <- data.frame(x[, var], .cluster = cluster, stringsAsFactors = FALSE)
+
+  }
+
+  #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+  ## Convert user-missing values into NA ####
+
+  if (isTRUE(!is.null(as.na))) { x[, var] <- .as.na(x[, var], na = as.na) }
 
   #_____________________________________________________________________________
   #
@@ -207,23 +301,6 @@ multilevel.omega <- function(x, cluster, rescov = NULL, const = c("within", "sha
 
     }
 
-    # Cluster specified with variable name
-    if (isTRUE(length(cluster) == 1L)) {
-
-      # Character cluster variable
-      if (isTRUE(!is.character(cluster))) { stop("Please specify a character string for the name of the cluster variable in 'x'", call. = FALSE) }
-
-      # Cluster variable in 'x'
-      if (isTRUE(!cluster %in% colnames(x))) { stop(paste0("Cluster variable \"", cluster, "\" specified in the argument 'cluster' was not found in 'x'"), call. = FALSE) }
-
-    # Cluster specified with vector
-    } else {
-
-      # Length of cluster variable
-      if (isTRUE(nrow(x) != length(cluster))) { stop("Cluster variable specified in the argument 'cluster' does not match with the number of rows in 'x'.", call. = FALSE) }
-
-    }
-
     # Check input 'rescov'
     if (isTRUE(!is.null(rescov))) {
 
@@ -266,6 +343,9 @@ multilevel.omega <- function(x, cluster, rescov = NULL, const = c("within", "sha
     # Check input 'digits'
     if (isTRUE(digits %% 1L != 0L || digits < 0L || digits == 0L)) { stop("Specify a positive integer number for the argument 'digits'.", call. = FALSE) }
 
+    # Check input 'append'
+    if (isTRUE(!is.logical(append))) { stop("Please specify TRUE or FALSE for the argument 'append'.", call. = FALSE) }
+
     # Check input 'output'
     if (isTRUE(!is.logical(output))) { stop("Please specify TRUE or FALSE for the argument 'output'.", call. = FALSE) }
 
@@ -306,40 +386,6 @@ multilevel.omega <- function(x, cluster, rescov = NULL, const = c("within", "sha
 
   }
 
-  #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-  ## Manifest variables ####
-
-  # Cluster variable in the data
-  if (isTRUE(length(cluster) == 1L)) { var <- colnames(x)[!colnames(x) %in% cluster] } else { var <- colnames(x) }
-
-  #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-  ## Data frame with Cluster Variable ####
-
-  # Cluster variable in the data
-  if (isTRUE(length(cluster) == 1L)) {
-
-    x <- data.frame(x[, var], .cluster = x[, cluster], stringsAsFactors = FALSE)
-
-  # Cluster variable specified in the argument 'cluster'
-  } else {
-
-    x <- data.frame(x[, var], .cluster = cluster, stringsAsFactors = FALSE)
-
-  }
-
-  #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-  ## Convert user-missing values into NA ####
-
-  if (isTRUE(!is.null(as.na))) {
-
-    x[, var] <- misty::as.na(x[, var], na = as.na, check = check)
-
-    # Variable with missing values only
-    x.miss <- vapply(x[, var], function(y) all(is.na(y)), FUN.VALUE = logical(1L))
-    if (isTRUE(any(x.miss))) { stop(paste0("After converting user-missing values into NA, following ", ifelse(length(which(x.miss)) == 1L, "variable is ", "variables are "), "completely missing: ", paste(names(which(x.miss)), collapse = ", ")), call. = FALSE) }
-
-  }
-
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
   ## Type of construct(s) ####
 
@@ -396,7 +442,7 @@ multilevel.omega <- function(x, cluster, rescov = NULL, const = c("within", "sha
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
   ## Model Estimation ####
 
-  model.fit <- tryCatch(suppressWarnings(misty::multilevel.cfa(x = x, cluster = ".cluster", model = NULL, rescov = rescov,
+  model.fit <- tryCatch(suppressWarnings(misty::multilevel.cfa(x, cluster = ".cluster", model = NULL, rescov = rescov,
                                          model.w = NULL, model.b = NULL, rescov.w = NULL, rescov.b = NULL,
                                          const = const, fix.resid = fix.resid, ident = "var", ls.fit = FALSE,
                                          estimator = "ML", optim.method = optim.method,
@@ -752,7 +798,7 @@ multilevel.omega <- function(x, cluster, rescov = NULL, const = c("within", "sha
                              optim.method = optim.method, missing = missing,
                              nrep = nrep, seed = seed, conf.level = conf.level,
                              print = print, digits = digits, as.na = as.na,
-                             check = check, output = output),
+                             write = write, append = append, check = check, output = output),
                  model = model.fit$model,
                  model.fit = model.fit$model.fit,
                  result = list(omega = omega, itemstat = itemstat))
@@ -763,7 +809,34 @@ multilevel.omega <- function(x, cluster, rescov = NULL, const = c("within", "sha
   #
   # Write Results --------------------------------------------------------------
 
-  if (isTRUE(!is.null(write))) { misty::write.result(object, file = write) }
+  if (isTRUE(!is.null(write))) {
+
+    #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+    ## Text file ####
+
+    if (isTRUE(grepl("\\.txt", write))) {
+
+      # Send R output to textfile
+      sink(file = write, append = ifelse(isTRUE(file.exists(write)), append, FALSE), type = "output", split = FALSE)
+
+      if (append && isTRUE(file.exists(write))) { write("", file = write, append = TRUE) }
+
+      # Print object
+      print(object, check = FALSE)
+
+      # Close file connection
+      sink()
+
+    #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+    ## Excel file ####
+
+    } else {
+
+      misty::write.result(object, file = write)
+
+    }
+
+  }
 
   #_____________________________________________________________________________
   #
